@@ -20,7 +20,11 @@ def login():
     if data == {}:
         cprint("Esa cuenta no existe intentalo otra vez", "red")
         si_no = input("\n¿Quieres crearte una? [s/n] :: ")
-        webbrowser.open('http://127.0.0.1:5000/login', new=2) if input == "s" else exit(0)
-        return login()
+        if input == "s":
+            webbrowser.open('http://127.0.0.1:5000/login', new=2)
+            return login()
+        else:
+            cprint("Veo que no", "red")
+            exit(0)
 
     return data
